"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const yeoman_test_1 = __importDefault(require("yeoman-test"));
const shared_1 = require("../../../../shared");
describe("toHaveDevDependency", () => {
    describe("when given something that isn't a YeomanTest.RunResult", () => {
        it("fails on a number", () => {
            expect(() => {
                expect(2).toHaveDevDependency("node");
            }).toThrow("Expected 2 to be a YeomanTest.RunResult");
        });
        it("fails on a boolean", () => {
            expect(() => {
                expect(true).toHaveDevDependency("node");
            }).toThrow("Expected true to be a YeomanTest.RunResult");
        });
        it("fails on a string", () => {
            expect(() => {
                expect("foobar").toHaveDevDependency("node");
            }).toThrow("Expected foobar to be a YeomanTest.RunResult");
        });
        it("fails on an empty object", () => {
            expect(() => {
                expect({}).toHaveDevDependency("node");
            }).toThrow("Expected [object Object] to be a YeomanTest.RunResult");
        });
        it("fails on a function", () => {
            const nullOp = () => {
                return;
            };
            expect(() => {
                expect(nullOp).toHaveDevDependency("node");
            }).toThrow(`Expected ${nullOp.toString()} to be a YeomanTest.RunResult`);
        });
    });
    describe("when given a YeomanTest.RunResult", () => {
        let result;
        describe("that contains a package.json file with devDependencies", () => {
            beforeAll(async () => {
                result = await yeoman_test_1.default.create(DevDependenciesTestGenerator, {
                    namespace: "test:dev-dependencies",
                }).run();
            });
            describe("and not provided a dependency version", () => {
                it("passes if the package.json lists the provided devDependency", () => {
                    expect(() => {
                        expect(result).toHaveDevDependency("typescript");
                    }).not.toThrow();
                });
                it("fails if the package.json does not list the provided devDependency", () => {
                    expect(() => {
                        expect(result).toHaveDevDependency("eslint");
                    }).toThrow("Expected run result package.json to have devDependency eslint");
                });
            });
            describe("and provided a dependency version", () => {
                it("passes if the package.json in the result has a devDependency with a matching version", () => {
                    expect(() => {
                        expect(result).toHaveDevDependency("typescript", "4.7.4");
                    }).not.toThrow();
                });
                it("fails if the package.json in the result has a matching devDependency but without a matching version", () => {
                    expect(() => {
                        expect(result).toHaveDevDependency("typescript", "1.0.0");
                    }).toThrow("Expected run result package.json to have devDependency typescript with version 1.0.0");
                });
                it("fails if the package.json in the result does not have a matching devDependency", () => {
                    expect(() => {
                        expect(result).toHaveDevDependency("eslint", "1.0.0");
                    }).toThrow("Expected run result package.json to have devDependency eslint with version 1.0.0");
                });
            });
        });
        describe("that contains a package.json file without devDependencies", () => {
            beforeAll(async () => {
                result = await yeoman_test_1.default.create(NoDevDependenciesTestGenerator, {
                    namespace: "test:no-dev-dependencies",
                }).run();
            });
            it("fails with an error about devDependencies being missing", () => {
                expect(() => {
                    expect(result).toHaveDevDependency("typescript");
                }).toThrow("Expected run result package.json to have a devDependencies key");
            });
        });
        describe("that does not contain a package.json file", () => {
            beforeAll(async () => {
                result = await yeoman_test_1.default.create(EmptyTestGenerator, {
                    namespace: "test:empty",
                }).run();
            });
            it("fails with an error about package.json being missing", () => {
                expect(() => {
                    expect(result).toHaveDevDependency("typescript", "1.0.0");
                }).toThrow("Expected run result to contain a package.json file");
            });
        });
    });
});
class DevDependenciesTestGenerator extends shared_1.BaseGenerator {
    async writing() {
        await this.addDevDependencies({
            typescript: "4.7.4",
        });
    }
}
class NoDevDependenciesTestGenerator extends shared_1.BaseGenerator {
    async writing() {
        await this.addDependencies({
            "react-redux": "17.0.0",
        });
    }
}
class EmptyTestGenerator extends shared_1.BaseGenerator {
    writing() {
        return;
    }
}
//# sourceMappingURL=toHaveDevDependency.matcher.test.js.map